@@ -1,15 +1,42 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006,2007,2010 Guido Guenther <agx@sigxcpu.org>
+# (C) 2006,2007,2010,2011 Guido Guenther <agx@sigxcpu.org>
 """handles command line and config file option parsing for the gbp commands"""
 
-from optparse import OptionParser, OptionGroup
+from optparse import OptionParser, OptionGroup, Option, OptionValueError
 from ConfigParser import SafeConfigParser
+from copy import copy
 import os.path
 try:
     from gbp.gbp_version import gbp_version
 except ImportError:
     gbp_version = "[Unknown version]"
+import gbp.tristate
+
+no_upstream_branch_msg = """
+Repository does not have branch '%s' for upstream sources. If there is none see
+file:///usr/share/doc/git-buildpackage/manual-html/gbp.import.html#GBP.IMPORT.CONVERT
+on howto create it otherwise use --upstream-branch to specify it.
+"""
+
+def expand_path(option, opt, value):
+    value = os.path.expandvars(value)
+    return os.path.expanduser(value)
+
+def check_tristate(option, opt, value):
+    try:
+        val = gbp.tristate.Tristate(value)
+    except TypeError:
+        raise OptionValueError(
+            "option %s: invalid value: %r" % (opt, value))
+    else:
+        return val
+
+class GbpOption(Option):
+    TYPES = Option.TYPES + ('path', 'tristate')
+    TYPE_CHECKER = copy(Option.TYPE_CHECKER)
+    TYPE_CHECKER['path'] = expand_path
+    TYPE_CHECKER['tristate'] = check_tristate
 
 class GbpOptionParser(OptionParser):
     """
@@ -63,10 +90,23 @@ class GbpOptionParser(OptionParser):
                  'compression'     : 'auto',
                  'compression-level': '9',
                  'remote-url-pattern' : 'ssh://alioth.debian.org/git/collab-maint/%(pkg)s.git',
-                 'multimaint-merge' : 'False',
+                 'multimaint'      : 'True',
+                 'multimaint-merge': 'False',
                  'pbuilder'        : 'False',
                  'dist'            : 'sid',
                  'arch'            : '',
+                 'interactive'     : 'True',
+                 'color'           : 'auto',
+                 'customizations'  : '',
+                 'spawn-editor'    : 'release',
+                 'patch-numbers'   : 'True',
+                 'notify'          : 'auto',
+                 'merge'           : 'True',
+                 'track'           : 'True',
+                 'author-is-committer': 'False',
+                 'author-date-is-committer-date': 'False',
+                 'create-missing-branches': 'False',
+                 'submodules'      : 'False',
              }
     help = {
              'debian-branch':
@@ -103,6 +143,8 @@ class GbpOptionParser(OptionParser):
                   "extract orig tarball when using export-dir option, default is '%(overlay)s'",
              'remote-url-pattern':
                   "Remote url pattern to create the repo at, default is '%(remote-url-pattern)s'",
+             'multimaint':
+                  "Note multiple maintainers, default is '%(multimaint)s'",
              'multimaint-merge':
                   "Merge commits by maintainer, default is '%(multimaint-merge)s'",
              'pbuilder':
@@ -111,6 +153,30 @@ class GbpOptionParser(OptionParser):
                   "Build for this distribution when using git-pbuilder, default is '%(dist)s'",
              'arch':
                   "Build for this architecture when using git-pbuilder, default is '%(arch)s'",
+             'interactive':
+                  "Run command interactive, default is '%(interactive)s'",
+             'color':
+                  "color output, default is '%(color)s'",
+             'spawn-editor':
+                  "Whether to spawn an editor after adding the changelog entry, default is '%(spawn-editor)s'",
+             'patch-numbers':
+                  "Whether to number patch files, default is %(patch-numbers)s",
+             'notify':
+                  "Whether to send a desktop notification after the build, default is '%(notify)s'",
+             'merge':
+                  "after the import merge the result to the debian branch, default is '%(merge)s'",
+             'track':
+                  "set up tracking for remote branches, default is '%(track)s'",
+             'author-is-committer':
+                  "Use the authors's name also as the comitter's name, default is '%(author-is-committer)s'",
+             'author-date-is-committer-date':
+                  "Use the authors's date as the comitter's date, default is '%(author-date-is-committer-date)s'",
+             'create-missing-branches':
+                  "Create missing branches automatically, default is '%(create-missing-branches)s'",
+             'submodules':
+                  "Transparently handle submodules in the upstream tree, default is '%(submodules)s'",
+             'postimport':
+                  "hook run after a successful import, default is '%(postimport)s'",
            }
     config_files = [ '/etc/git-buildpackage/gbp.conf',
                      os.path.expanduser('~/.gbp.conf'),
@@ -139,9 +205,9 @@ class GbpOptionParser(OptionParser):
         self.prefix = prefix
         self.config = {}
         self.__parse_config_files()
-        OptionParser.__init__(self, usage=usage, version='%s %s' % (self.command, gbp_version))
+        OptionParser.__init__(self, option_class=GbpOption, usage=usage, version='%s %s' % (self.command, gbp_version))
 
-    def _is_boolean(self, option_name, *args, **kwargs):
+    def _is_boolean(self, dummy, *unused, **kwargs):
         """is option_name a boolean option"""
         ret = False
         try:
