@@ -6,10 +6,15 @@ import os
 import unittest
 
 class TestHelp(unittest.TestCase):
-
-    def testhelp(self):
+    """Test help output of gbp commands"""
+    def testHelp(self):
         for prog in [ "buildpackage", "import-orig", "import-dsc", "dch" ]:
             ret = os.system("./git-%s --help >/dev/null" % prog)
             self.assertEqual(ret, 0)
 
+    def testHelpGbp(self):
+        for prog in [ "pull", "clone", "pq", "create-remote-repo" ]:
+            ret = os.system("./gbp-%s --help >/dev/null" % prog)
+            self.assertEqual(ret, 0)
+
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
